# $Id: pseudoxml.py 7320 2012-01-19 22:33:02Z milde $
# Author: David Goodger <goodger@python.org>
# Copyright: This module has been placed in the public domain.

"""
Simple internal document tree Writer, writes indented pseudo-XML.
"""

__docformat__ = 'reStructuredText'


from docutils import writers


class Writer(writers.Writer):

    supported = ('pprint', 'pformat', 'pseudoxml')
    """Formats this writer supports."""

    config_section = 'pseudoxml writer'
    config_section_dependencies = ('writers',)

    output = None
    """Final translated form of `document`."""

    def translate(self):
        self.output = self.document.pformat()

    def supports(self, format):
        """This writer supports all format-specific elements."""
        return True



#!/var/folders/sy/f16zz6x50xz3113nwtb9bvq00000gp/T/abs_10qo10r70f/croot/docutils_1685117199371/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/bin/python

# $Id: rst2odt.py 5839 2009-01-07 19:09:28Z dkuhlman $
# Author: Dave Kuhlman <dkuhlman@rexx.com>
# Copyright: This module has been placed in the public domain.

"""
A front end to the Docutils Publisher, producing OpenOffice documents.
"""

import sys
try:
    import locale
    locale.setlocale(locale.LC_ALL, '')
except:
    pass

from docutils.core import publish_cmdline_to_binary, default_description
from docutils.writers.odf_odt import Writer, Reader


description = ('Generates OpenDocument/OpenOffice/ODF documents from '
               'standalone reStructuredText sources.  ' + default_description)


writer = Writer()
reader = Reader()
output = publish_cmdline_to_binary(reader=reader, writer=writer,
    description=description)




# -*- coding: utf-8 -*-
# $Id: ko.py 8253 2019-04-15 10:01:10Z milde $
# Author: Thomas SJ Kang <thomas.kangsj@ujuc.kr>
# Copyright: This module has been placed in the public domain.

# New language mappings are welcome.  Before doing a new translation, please
# read <http://docutils.sf.net/docs/howto/i18n.html>.  Two files must be
# translated for each language: one in docutils/languages, the other in
# docutils/parsers/rst/languages.

"""
Korean-language mappings for language-dependent features of Docutils.
"""

__docformat__ = 'reStructuredText'

labels = {
      # fixed: language-dependent
      'author': u'저자',
      'authors': u'저자들',
      'organization': u'조직',
      'address': u'주소',
      'contact': u'연락처',
      'version': 'Version',
      'revision': 'Revision',
      'status': u'상태',
      'date': u'날짜',
      'copyright': u'저작권',
      'dedication': u'헌정',
      'abstract': u'요약',
      'attention': u'집중!',
      'caution': u'주의!',
      'danger': u'!위험!',
      'error': u'오류',
      'hint': u'실마리',
      'important': u'중요한',
      'note': u'비고',
      'tip': u'팁',
      'warning': u'경고',
      'contents': u'목차'}
"""Mapping of node class name to label text."""

bibliographic_fields = {
      # language-dependent: fixed
      u'저자': 'author',
      u'저자들': 'authors',
      u'조직': 'organization',
      u'주소': 'address',
      u'연락처': 'contact',
      u'version': 'version',
      u'revision': 'revision',
      u'상태': 'status',
      u'날짜': 'date',
      u'저작권': 'copyright',
      u'헌정': 'dedication',
      u'요약': 'abstract'}
"""Korean to canonical name mapping for bibliographic fields."""

author_separators = [';', ',']
"""List of separator strings for the 'Authors' bibliographic field. Tried in
order."""
